﻿using Syncfusion.WinForms.DataGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace sfDatagrid_MasterDetail_Issue
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private DataSet GenerateDataset()
        {
            DataSet dsResult = new DataSet();

            // Customer table
            DataTable dtCustomer = new DataTable("Customer");
            dtCustomer.Columns.Add("ID", typeof(int));
            dtCustomer.Columns.Add("CustomerName", typeof(string));

            System.Data.DataRow drCustomer1 = dtCustomer.NewRow();
            drCustomer1["ID"] = 1; 
            drCustomer1["CustomerName"] = "Alan Johnson"; 
            dtCustomer.Rows.Add(drCustomer1);

            System.Data.DataRow drCustomer2 = dtCustomer.NewRow();
            drCustomer2["ID"] = 2;
            drCustomer2["CustomerName"] = "Mike Wallace";
            dtCustomer.Rows.Add(drCustomer2);

            System.Data.DataRow drCustomer3 = dtCustomer.NewRow();
            drCustomer3["ID"] = 3;
            drCustomer3["CustomerName"] = "Mark Thomas";
            dtCustomer.Rows.Add(drCustomer3);

            //Sales Header
            DataTable dtSalesHeader = new DataTable("SalesHeader");
            dtSalesHeader.Columns.Add("ID", typeof(int));
            dtSalesHeader.Columns.Add("CustomerID", typeof(int));
            dtSalesHeader.Columns.Add("InvoiceNo", typeof(string));
            dtSalesHeader.Columns.Add("TotalAmount", typeof(decimal));

            System.Data.DataRow drSalesHeader1 = dtSalesHeader.NewRow();
            drSalesHeader1["ID"] = 1;
            drSalesHeader1["CustomerID"] = 1;
            drSalesHeader1["InvoiceNo"] = "INV-0001";
            drSalesHeader1["TotalAmount"] = 100.00M;
            dtSalesHeader.Rows.Add(drSalesHeader1);

            //Sales Detail
            DataTable dtSalesDetail = new DataTable("SalesDetail");
            dtSalesDetail.Columns.Add("ID", typeof(int));
            dtSalesDetail.Columns.Add("SalesHeaderID", typeof(int));
            dtSalesDetail.Columns.Add("ItemName", typeof(string));
            dtSalesDetail.Columns.Add("ItemAmount", typeof(decimal));

            System.Data.DataRow drSalesDetail1 = dtSalesDetail.NewRow();
            drSalesDetail1["ID"] = 1;
            drSalesDetail1["SalesHeaderID"] = 1;
            drSalesDetail1["ItemName"] = "Microsoft USB Mouse";
            drSalesDetail1["ItemAmount"] = 30.00M;
            dtSalesDetail.Rows.Add(drSalesDetail1);

            System.Data.DataRow drSalesDetail2 = dtSalesDetail.NewRow();
            drSalesDetail2["ID"] = 2;
            drSalesDetail2["SalesHeaderID"] = 1;
            drSalesDetail2["ItemName"] = "Logitech Keyboard";
            drSalesDetail2["ItemAmount"] = 70.00M;
            dtSalesDetail.Rows.Add(drSalesDetail2);

            dsResult.Tables.Add(dtCustomer);
            dsResult.Tables.Add(dtSalesHeader);
            dsResult.Tables.Add(dtSalesDetail);

            DataRelation relation1 = new DataRelation("Customer_SalesHeader", dsResult.Tables["Customer"].Columns["ID"], dsResult.Tables["SalesHeader"].Columns["CustomerID"]);
            relation1.Nested = true;

            DataRelation relation2 = new DataRelation("SalesHeader_SalesDetail", dsResult.Tables["SalesHeader"].Columns["ID"], dsResult.Tables["Salesdetail"].Columns["SalesHeaderID"]);
            relation2.Nested = true;

            dsResult.Relations.Add(relation1);
            dsResult.Relations.Add(relation2);


            return dsResult;            
        }

        private void PopulateDataGrid()
        {
            GridViewDefinition gridViewDefinition1 = new GridViewDefinition();
            GridViewDefinition gridViewDefinition2 = new GridViewDefinition();

            sfDataGrid1.AutoGenerateColumns = true;
            sfDataGrid1.AutoGenerateRelations = false;
            sfDataGrid1.NotifyEventsToParentDataGrid = false;
            sfDataGrid1.SelectionMode = Syncfusion.WinForms.DataGrid.Enums.GridSelectionMode.Single;

            //GridViewDefinition for DataGrid (Customer_SalesHeader)
            gridViewDefinition1.RelationalColumn = "Customer_SalesHeader";
            gridViewDefinition1.DataGrid = new SfDataGrid()
            {
                Name = "CustomerSalesHeaderNestedGrid",
                AutoGenerateColumns = true,
                NotifyEventsToParentDataGrid = false,
                AutoSizeColumnsMode = Syncfusion.WinForms.DataGrid.Enums.AutoSizeColumnsMode.Fill,
                SelectionMode = Syncfusion.WinForms.DataGrid.Enums.GridSelectionMode.Single
        };

            gridViewDefinition1.DataGrid.CellClick += Customer_SalesHeader_CellClick;

            //GridViewDefinition for DataGrid (SalesHeader_SalesDetail)
            gridViewDefinition2.RelationalColumn = "SalesHeader_SalesDetail";
            gridViewDefinition2.DataGrid = new SfDataGrid()
            {
                Name = "SalesHeaderSalesDetailNestedGrid",
                AutoGenerateColumns = true,
                NotifyEventsToParentDataGrid = false,
                AutoSizeColumnsMode = Syncfusion.WinForms.DataGrid.Enums.AutoSizeColumnsMode.Fill,
                SelectionMode = Syncfusion.WinForms.DataGrid.Enums.GridSelectionMode.Single
            };

            gridViewDefinition2.DataGrid.CellClick += SalesHeader_SalesDetail_CellClick;



            gridViewDefinition1.DataGrid.DetailsViewDefinitions.Add(gridViewDefinition2);

            sfDataGrid1.DetailsViewDefinitions.Add(gridViewDefinition1);



            sfDataGrid1.DataSource = GenerateDataset().Tables[0];
        }

        private void button1_Click(object sender, EventArgs e)
        {
            PopulateDataGrid();
        }

        private void Customer_SalesHeader_CellClick(object sender, Syncfusion.WinForms.DataGrid.Events.CellClickEventArgs e)
        {
            // Get the row index value        
            var rowIndex = e.DataRow.RowIndex;
            //Get the column index value
            var columnIndex = e.DataColumn.ColumnIndex;

            if (columnIndex <= 0) return;

            //Get the cell value            
            var cellValue = this.sfDataGrid1.View.GetPropertyAccessProvider().GetValue(e.DataRow.RowData, e.DataColumn.GridColumn.MappingName);
            MessageBox.Show("Cell Value \t:    " + cellValue + "\n" + "Row Index \t:    " + rowIndex + "\n" + "Column Index \t:    " + columnIndex, "Cell Value");

        }

        private void SalesHeader_SalesDetail_CellClick(object sender, Syncfusion.WinForms.DataGrid.Events.CellClickEventArgs e)
        {
            // Get the row index value        
            var rowIndex = e.DataRow.RowIndex;
            //Get the column index value
            var columnIndex = e.DataColumn.ColumnIndex;

            if (columnIndex <= 0) return;

            //Get the cell value            
            var cellValue = this.sfDataGrid1.View.GetPropertyAccessProvider().GetValue(e.DataRow.RowData, e.DataColumn.GridColumn.MappingName);
            MessageBox.Show("Cell Value \t:    " + cellValue + "\n" + "Row Index \t:    " + rowIndex + "\n" + "Column Index \t:    " + columnIndex, "Cell Value");

        }

        private void Form1_Shown(object sender, EventArgs e)
        {
            //PopulateDataGrid();
        }
    }
}
